# Generated by Django 3.2 on 2022-11-10 11:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('apis_ampel', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='ampelsettings',
            old_name='_active',
            new_name='active',
        ),
        migrations.RenameField(
            model_name='ampelsettings',
            old_name='_content_type',
            new_name='content_type',
        ),
    ]
