# Generated by Django 3.2 on 2022-11-11 10:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('apis_metainfo', '0006_remove_text_lang'),
        ('apis_ampel', '0004_alter_ampeltemp_temp_entity'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ampeltemp',
            name='id',
        ),
        migrations.AlterField(
            model_name='ampeltemp',
            name='temp_entity',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, related_name='ampel', serialize=False, to='apis_metainfo.tempentityclass'),
        ),
    ]
