# Generated by Django 3.2 on 2022-11-11 09:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('apis_ampel', '0002_auto_20221110_1150'),
    ]

    operations = [
        migrations.DeleteModel(
            name='AmpelGeneric',
        ),
    ]
